@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
 
-############################ Copyrights and license ############################
+# ########################## Copyrights and license ############################
 #                                                                              #
 # Copyright 2012 Vincent Jacques <vincent@vincent-jacques.net>                 #
 # Copyright 2012 Zearin <zearin@gonk.net>                                      #
+# Copyright 2013 AKFish <akfish@gmail.com>                                     #
 # Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
 #                                                                              #
 # This file is part of PyGithub. http://jacquev6.github.com/PyGithub/          #
@@ -21,7 +22,7 @@
 # You should have received a copy of the GNU Lesser General Public License     #
 # along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
 #                                                                              #
-################################################################################
+# ##############################################################################
 
 import os
 import sys
@@ -244,8 +245,24 @@ class BasicTestCase(unittest.TestCase):
 
 
 class TestCase(BasicTestCase):
+    def doCheckFrame(self, obj, frame):
+        if obj._headers == {} and frame is None:
+            return
+        if obj._headers is None and frame == {}:
+            return
+        self.assertEqual(obj._headers, frame[2])
+
+    def getFrameChecker(self):
+        return lambda requester, obj, frame: self.doCheckFrame(obj, frame)
+
     def setUp(self):
         BasicTestCase.setUp(self)
+
+        # Set up frame debugging
+        github.GithubObject.GithubObject.setCheckAfterInitFlag(True)
+        github.Requester.Requester.setDebugFlag(True)
+        github.Requester.Requester.setOnCheckMe(self.getFrameChecker())
+
         self.g = github.Github(self.login, self.password)
 
 
